# Change Log 

* Version 0.0.1 (2021-07-07)
	* Include two function scripts

* Version 0.0.2 (2021-07-08)
	* bug fixed
	* new functions added

* Version 0.0.3 (2021-07-09)
	* solve the README.md issue

* Version 0.0.9 (2021-07-10)
	* require pymannkendall package 
